# DashWindowCloseListener

DashWindowCloseListener is a Dash component library that allows you to listen to the browser window close event. This can be used to stop the Dash server when the user closes his window, which is useful when using Dash apps as part of a multi step a workflow.

This is illustrated in the following example:

Get started with:
1. Install Dash and its dependencies: `pip install -r requirements.txt`(https://dash.plotly.com/installation)
2. Run `python usage.py`
3. Visit http://localhost:8050 in your web browser
4. When closing the browser window, the dash server will stop.

## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md)


